import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import { createStore as reduxCreateStore, applyMiddleware, combineReducers } from 'redux';
import { routerReducer, routerMiddleware } from 'react-router-redux';
import { composeWithDevTools } from 'redux-devtools-extension';
import uuid from 'uuid/v4';
import createViewModelsReducer from './create_view_models_reducer';
import createReadModelsReducer from './create_read_models_reducer';
import createJwtReducer from './create_jwt_reducer';
import createResolveMiddleware from './create_resolve_middleware';
import syncJwtProviderWithStore from './sync_jwt_provider_with_store';

var createStore = function createStore(_ref) {
  var _ref$redux = _ref.redux,
      reducers = _ref$redux.reducers,
      middlewares = _ref$redux.middlewares,
      setupStore = _ref$redux.store,
      viewModels = _ref.viewModels,
      readModels = _ref.readModels,
      aggregates = _ref.aggregates,
      subscribeAdapter = _ref.subscribeAdapter,
      initialState = _ref.initialState,
      history = _ref.history,
      origin = _ref.origin,
      rootPath = _ref.rootPath,
      jwtProvider = _ref.jwtProvider,
      isClient = _ref.isClient;
  var sessionId = uuid();
  var resolveMiddleware = createResolveMiddleware();
  var store = reduxCreateStore(combineReducers(_objectSpread({}, reducers, {
    router: routerReducer,
    viewModels: createViewModelsReducer(viewModels),
    readModels: createReadModelsReducer(readModels),
    jwt: createJwtReducer()
  })), initialState, composeWithDevTools(applyMiddleware.apply(void 0, [routerMiddleware(history), resolveMiddleware].concat(middlewares))));
  resolveMiddleware.run({
    store: store,
    viewModels: viewModels,
    readModels: readModels,
    aggregates: aggregates,
    origin: origin,
    rootPath: rootPath,
    subscribeAdapter: subscribeAdapter,
    sessionId: sessionId,
    jwtProvider: jwtProvider,
    isClient: isClient
  });
  setupStore(store, middlewares);
  syncJwtProviderWithStore(jwtProvider, store).catch( // eslint-disable-next-line no-console
  function (error) {
    return console.error(error);
  });
  return store;
};

export default createStore;
//# sourceMappingURL=create_store.js.map